@@ -8,8 +8,8 @@ class PostgreDumpDatabaseTask(DumpDatabaseTask, Task):
 
     name = 'dump'
 
-    def get_command(self, env, file_name):
-        return ('pg_dump --username="%(db_username)s" "%(db_name)s" > ' % env) + file_name
+    def get_command(self, env, file_name, **flags):
+        return ('pg_dump --no-owner ' + self.get_flags_string(**flags) + ' --username="%(db_username)s" "%(db_name)s" > ' % env) + file_name
 
 dump = PostgreDumpDatabaseTask()
-download = DownloadDatabase(dump_task=dump)
\ No newline at end of file
+download = DownloadDatabase(dump_task=dump)
